==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-panel/plugin-mount/mount_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Συνδέθηκε η συσκευή &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="53"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Αφαιρέθηκε η συσκευή &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="59"/>
        <source>Removable media/devices manager</source>
        <translation>Διαχειριστής αφαιρούμενων μέσων/συσκευών</translation>
    </message>
</context>
<context>
    <name>LXQtMountConfiguration</name>
    <message>
        <source>LXQt Removable media manager settings</source>
        <translation type="vanished">Ρυθμίσεις διαχειριστή αφαιρούμενων μέσων LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtmountconfiguration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation>Ρυθμίσεις αφαιρούμενων μέσων</translation>
    </message>
    <message>
        <location filename="../../../lxqtmountconfiguration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Συμπεριφορά</translation>
    </message>
    <message>
        <location filename="../../../lxqtmountconfiguration.ui" line="26"/>
        <source>When a device is connected </source>
        <translation>Όταν μια συσκευή συνδέεται </translation>
    </message>
    <message>
        <location filename="../../../lxqtmountconfiguration.cpp" line="44"/>
        <source>Popup menu</source>
        <translation>Αναδυόμενο μενού</translation>
    </message>
    <message>
        <location filename="../../../lxqtmountconfiguration.cpp" line="45"/>
        <source>Show info</source>
        <translation>Εμφάνιση πληροφοριών</translation>
    </message>
    <message>
        <location filename="../../../lxqtmountconfiguration.cpp" line="46"/>
        <source>Do nothing</source>
        <translation>Καμία ενέργεια</translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <source>Click to access this device from other applications.</source>
        <translation type="vanished">Κλίκ για πρόσβαση σε αυτή τη συσκευή από άλλες εφαρμογές.</translation>
    </message>
    <message>
        <source>Click to eject this disc.</source>
        <translation type="vanished">Κλίκ για εξαγωγή αυτού του δίσκου.</translation>
    </message>
    <message>
        <location filename="../../../menudiskitem.cpp" line="120"/>
        <location filename="../../../menudiskitem.cpp" line="155"/>
        <source>Removable media/devices manager</source>
        <translation>Διαχειριστής αφαιρούμενων μέσων/συσκευών</translation>
    </message>
    <message>
        <location filename="../../../menudiskitem.cpp" line="121"/>
        <source>Mounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation>Η προσάρτηση του &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; απέτυχε: %2</translation>
    </message>
    <message>
        <location filename="../../../menudiskitem.cpp" line="156"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation>Η αποπροσάρτηση του &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; απέτυχε: %2</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <location filename="../../../mountbutton.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation>Διαχειριστής αφαιρούμενων μέσων/συσκευών</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation type="vanished">Συνδέθηκε η συσκευή &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation type="vanished">Αφαιρέθηκε η συσκευή &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>No devices Available.</source>
        <translation type="vanished">Καμία διαθέσιμη συσκευή.</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../../../popup.cpp" line="68"/>
        <source>No devices are available</source>
        <translation>Καμία διαθέσιμη συσκευή</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-mount/mount_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>Button</name>
    <message>
        <location filename="../../../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation>Διαχειριστής αφαιρούμενων μέσων/συσκευών</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../../../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation>Ρυθμίσεις αφαιρούμενων μέσων</translation>
    </message>
    <message>
        <location filename="../../../configuration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Συμπεριφορά</translation>
    </message>
    <message>
        <location filename="../../../configuration.ui" line="26"/>
        <source>When a device is connected :</source>
        <translation>Όταν μια συσκευή συνδέεται:</translation>
    </message>
    <message>
        <location filename="../../../configuration.cpp" line="40"/>
        <source>Popup menu</source>
        <translation>Αναδυόμενο μενού</translation>
    </message>
    <message>
        <location filename="../../../configuration.cpp" line="41"/>
        <source>Show info</source>
        <translation>Εμφάνιση πληροφοριών</translation>
    </message>
    <message>
        <location filename="../../../configuration.cpp" line="42"/>
        <source>Do nothing</source>
        <translation>Καμία ενέργεια</translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Συνδέθηκε η συσκευή &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Αφαιρέθηκε η συσκευή &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation>Διαχειριστής αφαιρούμενων μέσων/συσκευών</translation>
    </message>
</context>
<context>
    <name>LXQtMountConfiguration</name>
    <message>
        <source>LXQt Removable media manager settings</source>
        <translation>Ρυθμίσεις του διαχειριστή των αφαιρούμενων μέσων του LXQt</translation>
    </message>
    <message>
        <source>Removable Media Settings</source>
        <translation>Ρυθμίσεις των αφαιρούμενων μέσων</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation>Συμπεριφορά</translation>
    </message>
    <message>
        <source>When a device is connected </source>
        <translation>Όταν μια συσκευή συνδέεται </translation>
    </message>
    <message>
        <source>Popup menu</source>
        <translation>Αναδυόμενο μενού</translation>
    </message>
    <message>
        <source>Show info</source>
        <translation>Εμφάνιση πληροφοριών</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Καμία ενέργεια</translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <source>Click to access this device from other applications.</source>
        <translation>Κάντε κλικ για προσπέλαση της συσκευής από άλλες εφαρμογές.</translation>
    </message>
    <message>
        <source>Click to eject this disc.</source>
        <translation>Κάντε κλικ για την εξαγωγή του δίσκου.</translation>
    </message>
    <message>
        <location filename="../../../menudiskitem.cpp" line="155"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation>Η προσάρτηση του &lt;b&gt;&lt;nobr&gt;«%1»&lt;/nobr&gt;&lt;/b&gt; απέτυχε: %2</translation>
    </message>
    <message>
        <location filename="../../../menudiskitem.cpp" line="157"/>
        <location filename="../../../menudiskitem.cpp" line="178"/>
        <source>Removable media/devices manager</source>
        <translation>Διαχειριστής αφαιρούμενων μέσων/συσκευών</translation>
    </message>
    <message>
        <source>Mounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation>Η προσάρτηση του &lt;strong&gt;&lt;nobr&gt;«%1»&lt;/nobr&gt;&lt;/strong&gt; απέτυχε: %2</translation>
    </message>
    <message>
        <location filename="../../../menudiskitem.cpp" line="176"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation>Η αποπροσάρτηση του &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; απέτυχε: %2</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <source>Removable media/devices manager</source>
        <translation>Διαχειριστής των αφαιρούμενων μέσων/συσκευών</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Συνδέθηκε η συσκευή &lt;b&gt;&lt;nobr&gt;«%1»&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Αφαιρέθηκε η συσκευή &lt;b&gt;&lt;nobr&gt;«%1»&lt;/nobr&gt;&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>No devices Available.</source>
        <translation>Καμία διαθέσιμη συσκευή.</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../../../popup.cpp" line="68"/>
        <source>No devices are available</source>
        <translation>Καμία διαθέσιμη συσκευή</translation>
    </message>
</context>
</TS>
